==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIload.h <==
// class soot.coffi.Instruction_Iload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d270779541039c4f soot_coffi_Instruction__5fIload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fIload_H_
#define _JC_soot_coffi_Instruction__5fIload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIload$sub_refs	_jc_soot_coffi_Instruction__5fIload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIload$sub_nonrefs	_jc_soot_coffi_Instruction__5fIload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIload$refs	_jc_soot_coffi_Instruction__5fIload$refs;
typedef struct _jc_soot_coffi_Instruction__5fIload$nonrefs	_jc_soot_coffi_Instruction__5fIload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIload$object	_jc_soot_coffi_Instruction__5fIload$object;

typedef const struct _jc_soot_coffi_Instruction__5fIload$vmethods	_jc_soot_coffi_Instruction__5fIload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIload$vtable	_jc_soot_coffi_Instruction__5fIload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIload$vtype	_jc_soot_coffi_Instruction__5fIload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fIload$vmethods	soot_coffi_Instruction__5fIload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIload$refs {
    _jc_soot_coffi_Instruction__5fIload$sub_refs	soot_coffi_Instruction__5fIload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fIload$sub_nonrefs	soot_coffi_Instruction__5fIload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIload$object {
	_jc_soot_coffi_Instruction__5fIload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIload$vtype _jc_soot_coffi_Instruction__5fIload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIload.h <==
// class soot.coffi.Instruction_Iload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class d270779541039c4f soot_coffi_Instruction__5fIload
// @dep_class 73e8eecee99f809f soot_coffi_Instruction__5fbytevar

// header file dependencies
// @dep_header soot_coffi_Instruction__5fbytevar

#include "soot/coffi/Instruction__5fbytevar.h"

#ifndef _JC_soot_coffi_Instruction__5fIload_H_
#define _JC_soot_coffi_Instruction__5fIload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIload$sub_refs	_jc_soot_coffi_Instruction__5fIload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIload$sub_nonrefs	_jc_soot_coffi_Instruction__5fIload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIload$refs	_jc_soot_coffi_Instruction__5fIload$refs;
typedef struct _jc_soot_coffi_Instruction__5fIload$nonrefs	_jc_soot_coffi_Instruction__5fIload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIload$object	_jc_soot_coffi_Instruction__5fIload$object;

typedef const struct _jc_soot_coffi_Instruction__5fIload$vmethods	_jc_soot_coffi_Instruction__5fIload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIload$vtable	_jc_soot_coffi_Instruction__5fIload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIload$vtype	_jc_soot_coffi_Instruction__5fIload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbytevar$vmethods	soot_coffi_Instruction__5fbytevar;
	_jc_soot_coffi_Instruction__5fIload$vmethods	soot_coffi_Instruction__5fIload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIload$refs {
    _jc_soot_coffi_Instruction__5fIload$sub_refs	soot_coffi_Instruction__5fIload;
    _jc_soot_coffi_Instruction__5fbytevar$sub_refs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbytevar$sub_nonrefs	soot_coffi_Instruction__5fbytevar;
    _jc_soot_coffi_Instruction__5fIload$sub_nonrefs	soot_coffi_Instruction__5fIload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIload$object {
	_jc_soot_coffi_Instruction__5fIload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIload$vtype _jc_soot_coffi_Instruction__5fIload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIload_H_ */
